package Task::BeLike::SHARYANTO::Noted;

our $VERSION = '0.02'; # VERSION

1;
# ABSTRACT: Some modules which I take note of because I can never remember their names


__END__
=pod

=head1 NAME

Task::BeLike::SHARYANTO::Noted - Some modules which I take note of because I can never remember their names

=head1 VERSION

version 0.02

=head1 DESCRIPTION

This distribution is a random list of modules which I need to take a note of
because I can never seem to remember their names, usually because the name is
not representative of what the module does, or the term is unusual, or both. Or
it's just my failing memory.

They are categorized by functionalities/topics.

=head1 TASK CONTENTS

=head2 Modules to prevent multiple instances of script running simultaneously

Similar in functionality to L<Proc::PID::File>.

=head3 L<Sys::RunAlone>

=head1 FAQ

=head2 Why don't you just favorite the module in MetaCPAN?

I reserve that for modules which I like/use and would like to be installed on my
Perl installations.

=head1 AUTHOR

Steven Haryanto <stevenharyanto@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Steven Haryanto.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

